@@ -119,12 +119,12 @@
 #' When running simulations in parallel (either with \code{parallel = TRUE} or \code{MPI = TRUE})
 #' R objects defined in the global environment will generally \emph{not} be visible across nodes.
 #' Hence, you may see errors such as \code{Error: object 'something' not found} if you try to use
-#' an object that is defined in the workspace but is not passed to \code{runSimulation}.
+#' an object that is defined in the work space but is not passed to \code{runSimulation}.
 #' To avoid this type or error, simply pass additional objects to the
 #' \code{fixed_objects} input (usually it's convenient to supply a named list of these objects).
 #' Fortunately, however, \emph{custom functions defined in the global environment are exported across
 #' nodes automatically}. This makes it convenient when writing code because custom functions will
-#' always be available across nodes if they are visible in the R workspace. As well, note the
+#' always be available across nodes if they are visible in the R work space. As well, note the
 #' \code{packages} input to declare packages which must be loaded via \code{library()} in order to make
 #' specific non-standard R functions available across nodes.
 #'
@@ -360,6 +360,11 @@
 #'      \item{\code{MPI}}{logical (default is \code{FALSE}); use the \code{foreach} package in a
 #'        form usable by MPI to run simulation in parallel on a cluster? }
 #'
+#'      \item{\code{.options.mpi}}{list of arguments passed to \code{foreach()} to control the MPI execution
+#'        properties. Only used when \code{MPI = TRUE}}
+#'
+#'
+#'
 #'    }
 #'
 #' @param save_details a list pertaining to information regarding how and where files should be saved
@@ -853,6 +858,8 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                             FALSE, extra_options$stop_on_fatal)
     MPI <- ifelse(is.null(extra_options$MPI),
                   FALSE, extra_options$MPI)
+    .options.mpi <- ifelse(is.null(extra_options$.options.mpi),
+                           list(), extra_options$.options.mpi)
     type <- if(is.null(extra_options$type))
         ifelse(.Platform$OS.type == 'windows', 'PSOCK', 'FORK')
         else extra_options$type
@@ -1111,7 +1118,7 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                                            else design[i,],
                                          replications=replications,
                                          fixed_objects=fixed_objects,
-                                         cl=cl, MPI=MPI, seed=seed,
+                                         cl=cl, MPI=MPI, .options.mpi=.options.mpi, seed=seed,
                                          boot_draws=boot_draws, boot_method=boot_method, CI=CI,
                                          save=save, allow_na=allow_na, allow_nan=allow_nan,
                                          save_results=save_results,
@@ -1142,7 +1149,7 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                             condition=if(was_tibble) dplyr::as_tibble(design[i,]) else design[i,],
                             replications=replications,
                             fixed_objects=fixed_objects,
-                            cl=cl, MPI=MPI, seed=seed,
+                            cl=cl, MPI=MPI, .options.mpi=.options.mpi, seed=seed,
                             boot_method=boot_method, boot_draws=boot_draws, CI=CI,
                             save=save, allow_na=allow_na, allow_nan=allow_nan,
                             save_results=save_results,
